\DeclareOption*{\PassOptionsToClass{\CurrentOption}{slides}}
\ProcessOptions
\InputIfFileExists{jsfonts.cfg}
           {\typeout{**************************************^^J%
                     *^^J%
                     * Local config file jsfonts.cfg used^^J%
                     *^^J%
                     **************************************}}%
           {\input{jsfonts.def}}
\LoadClass{slides}
\DeclareOldFontCommand{\dm}{\jfontseries\jmddefault\selectfont}{\relax}
\DeclareOldFontCommand{\dg}{\jfontseries\jbfdefault\selectfont}{\relax}
\let\min\dm
\let\goth\dg
