%%
%% This is file `cp1250.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp1250')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at http://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright 1993-2016
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.



  \ProvidesFile{cp1250.def}
   [2015/03/17 v1.2c Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\DeclareInputText{128}{\texteuro}
\DeclareInputText{130}{\quotesinglbase}
\DeclareInputText{132}{\quotedblbase}
\DeclareInputText{133}{\dots}
\DeclareInputText{134}{\dag}
\DeclareInputText{135}{\ddag}
\DeclareInputText{137}{\textperthousand}
\DeclareInputText{138}{\v S}
\DeclareInputText{139}{\guilsinglleft}
\DeclareInputText{140}{\@tabacckludge'S}
\DeclareInputText{141}{\v T}
\DeclareInputText{142}{\v Z}
\DeclareInputText{143}{\@tabacckludge'Z}
\DeclareInputText{145}{\textquoteleft}
\DeclareInputText{146}{\textquoteright}
\DeclareInputText{147}{\textquotedblleft}
\DeclareInputText{148}{\textquotedblright}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textendash}
\DeclareInputText{151}{\textemdash}
\DeclareInputText{153}{\texttrademark}
\DeclareInputText{154}{\v s}
\DeclareInputText{155}{\guilsinglright}
\DeclareInputText{156}{\@tabacckludge's}
\DeclareInputText{157}{\v t} % t caron (t') ?
\DeclareInputText{158}{\v z}
\DeclareInputText{159}{\@tabacckludge'z}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\v{}}
\DeclareInputText{162}{\u{}}
\DeclareInputText{163}{\L}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{165}{\k A}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\"{}}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{\c S}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}% soft hyphen
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\.Z}
\DeclareInputText{176}{\textdegree}
\DeclareInputMath{177}{\pm}% plus-minus
\DeclareInputText{178}{\k\ }
\DeclareInputText{179}{\l}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputMath{181}{\mu}% micro sign
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\c\ }
\DeclareInputText{185}{\k a}
\DeclareInputText{186}{\c s}
\DeclareInputText{187}{\guillemotright}
\DeclareInputText{188}{\v L}% L caron (L') ?
\DeclareInputText{189}{\H{}}
\DeclareInputText{190}{\v l}% l caron (l') ?
\DeclareInputText{191}{\.z}
\DeclareInputText{192}{\@tabacckludge'R}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\^A}
\DeclareInputText{195}{\u A}
\DeclareInputText{196}{\"A}
\DeclareInputText{197}{\@tabacckludge'L}
\DeclareInputText{198}{\@tabacckludge'C}
\DeclareInputText{199}{\c C}
\DeclareInputText{200}{\v C}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\k E}
\DeclareInputText{203}{\"E}
\DeclareInputText{204}{\v E}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{206}{\^I}
\DeclareInputText{207}{\v D}
\DeclareInputText{208}{\DJ} % D stroke
\DeclareInputText{209}{\@tabacckludge'N}
\DeclareInputText{210}{\v N}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\^O}
\DeclareInputText{213}{\H O}
\DeclareInputText{214}{\"O}
\DeclareInputMath{215}{\times}
\DeclareInputText{216}{\v R}
\DeclareInputText{217}{\r U}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\H U}
\DeclareInputText{220}{\"U}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{222}{\c T}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge'r}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\^a}
\DeclareInputText{227}{\u a}
\DeclareInputText{228}{\"a}
\DeclareInputText{229}{\@tabacckludge'l}
\DeclareInputText{230}{\@tabacckludge'c}
\DeclareInputText{231}{\c c}
\DeclareInputText{232}{\v c}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\k e}
\DeclareInputText{235}{\"e}
\DeclareInputText{236}{\v e}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{238}{\^\i}
\DeclareInputText{239}{\v d} % d caron (d') ?
\DeclareInputText{240}{\dj} % d stroke
\DeclareInputText{241}{\@tabacckludge'n}
\DeclareInputText{242}{\v n}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\^o}
\DeclareInputText{245}{\H o}
\DeclareInputText{246}{\"o}
\DeclareInputMath{247}{\div}
\DeclareInputText{248}{\v r}
\DeclareInputText{249}{\r u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\H u}
\DeclareInputText{252}{\"u}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{254}{\c t}
\DeclareInputText{255}{\.{}}
\endinput
%%
%% End of file `cp1250.def'.
